bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD.delete
==============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOToGaussianGammaARD.delete